==> lasso_2.2.1.orig.tar.gz: lasso-2.2.1/lasso/xml/saml-2.0/samlp2_extensions.c <==
/* $Id: samlp2_extensions.c 3704 2008-05-15 21:17:44Z fpeters $ 
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 * 
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "samlp2_extensions.h"

/**
 * SECTION:samlp2_extensions
 * @short_description: &lt;samlp2:Extensions&gt;
 *
 * <figure><title>Schema fragment for samlp2:Extensions</title>
 * <programlisting><![CDATA[
 *
 * <complexType name="ExtensionsType">
 *   <sequence>
 *     <any namespace="##other" processContents="lax" maxOccurs="unbounded"/>
 *   </sequence>
 * </complexType>
 * ]]></programlisting>
 * </figure>
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{NULL, 0, 0}
};

static LassoNodeClass *parent_class = NULL;


/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/

static void
instance_init(LassoSamlp2Extensions *node)
{
}

static void
class_init(LassoSamlp2ExtensionsClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	lasso_node_class_set_nodename(nclass, "Extensions"); 
	lasso_node_class_set_ns(nclass, LASSO_SAML2_PROTOCOL_HREF, LASSO_SAML2_PROTOCOL_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_samlp2_extensions_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoSamlp2ExtensionsClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoSamlp2Extensions),
			0,
			(GInstanceInitFunc) instance_init,
		};

		this_type = g_type_register_static(LASSO_TYPE_NODE,
				"LassoSamlp2Extensions", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_samlp2_extensions_new:
 *
 * Creates a new #LassoSamlp2Extensions object.
 *
 * Return value: a newly created #LassoSamlp2Extensions object
 **/
LassoNode*
lasso_samlp2_extensions_new()
{
	return g_object_new(LASSO_TYPE_SAMLP2_EXTENSIONS, NULL);
}

==> lasso_2.3.6.orig.tar.gz: lasso-2.3.6/lasso/xml/saml-2.0/samlp2_extensions.c <==
/* $Id$
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 *
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "../private.h"
#include "samlp2_extensions.h"

/**
 * SECTION:samlp2_extensions
 * @short_description: &lt;samlp2:Extensions&gt;
 *
 * <figure><title>Schema fragment for samlp2:Extensions</title>
 * <programlisting><![CDATA[
 *
 * <complexType name="ExtensionsType">
 *   <sequence>
 *     <any namespace="##other" processContents="lax" maxOccurs="unbounded"/>
 *   </sequence>
 * </complexType>
 * ]]></programlisting>
 * </figure>
 *
 * To specify the content of this object you must attach an <type>xmlNode</type> to it using
 * lasso_node_set_original_xmlnode(). The content (attributes, children and namespaces) of this node
 * will be copied to the result node returned by calls to lasso_node_get_xmlNode().
 *
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{NULL, 0, 0, NULL, NULL, NULL}
};

static LassoNodeClass *parent_class = NULL;

/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/

static xmlNode*
get_xmlNode(LassoNode *node, gboolean lasso_dump)
{
	LassoNodeClass *parent_class = NULL;
	xmlNode *cur;

	parent_class = g_type_class_peek_parent(LASSO_NODE_GET_CLASS(node));
	cur = parent_class->get_xmlNode(node, lasso_dump);

	return lasso_node_get_xmlnode_for_any_type(node, cur);
}

static void
class_init(LassoSamlp2ExtensionsClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	nclass->node_data->keep_xmlnode = TRUE;
	nclass->get_xmlNode = get_xmlNode;
	lasso_node_class_set_nodename(nclass, "Extensions");
	lasso_node_class_set_ns(nclass, LASSO_SAML2_PROTOCOL_HREF, LASSO_SAML2_PROTOCOL_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_samlp2_extensions_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoSamlp2ExtensionsClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoSamlp2Extensions),
			0,
			NULL,
			NULL
		};

		this_type = g_type_register_static(LASSO_TYPE_NODE,
				"LassoSamlp2Extensions", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_samlp2_extensions_new:
 *
 * Creates a new #LassoSamlp2Extensions object.
 *
 * Return value: a newly created #LassoSamlp2Extensions object
 **/
LassoNode*
lasso_samlp2_extensions_new()
{
	return g_object_new(LASSO_TYPE_SAMLP2_EXTENSIONS, NULL);
}
